@@ -13,6 +13,7 @@ import (
 	"path/filepath"
 	"sort"
 	"strings"
+	"sync/atomic"
 
 	"github.com/syncthing/syncthing/lib/osutil"
 	"github.com/syncthing/syncthing/lib/protocol"
@@ -28,6 +29,7 @@ import (
 type deletionHandler func(t readWriteTransaction, folder, device, name []byte, dbi iterator.Iterator) int64
 
 type Instance struct {
+	committed int64 // this must be the first attribute in the struct to ensure 64 bit alignment on 32 bit plaforms
 	*leveldb.DB
 	folderIdx *smallIndex
 	deviceIdx *smallIndex
@@ -91,6 +93,11 @@ func newDBInstance(db *leveldb.DB) *Instance {
 	return i
 }
 
+// Committed returns the number of items committed to the database since startup
+func (db *Instance) Committed() int64 {
+	return atomic.LoadInt64(&db.committed)
+}
+
 func (db *Instance) genericReplace(folder, device []byte, fs []protocol.FileInfo, localSize, globalSize *sizeTracker, deleteFn deletionHandler) int64 {
 	sort.Sort(fileList(fs)) // sort list on name, same as in the database
 
@@ -339,7 +346,7 @@ func (db *Instance) getGlobal(folder, file []byte, truncate bool) (FileIntf, boo
 		panic(err)
 	}
 
-	var vl versionList
+	var vl VersionList
 	err = vl.UnmarshalXDR(bs)
 	if err != nil {
 		panic(err)
@@ -376,7 +383,7 @@ func (db *Instance) withGlobal(folder, prefix []byte, truncate bool, fn Iterator
 
 	var fk []byte
 	for dbi.Next() {
-		var vl versionList
+		var vl VersionList
 		err := vl.UnmarshalXDR(dbi.Value())
 		if err != nil {
 			panic(err)
@@ -428,7 +435,7 @@ func (db *Instance) availability(folder, file []byte) []protocol.DeviceID {
 		panic(err)
 	}
 
-	var vl versionList
+	var vl VersionList
 	err = vl.UnmarshalXDR(bs)
 	if err != nil {
 		panic(err)
@@ -456,7 +463,7 @@ func (db *Instance) withNeed(folder, device []byte, truncate bool, fn Iterator)
 	var fk []byte
 nextFile:
 	for dbi.Next() {
-		var vl versionList
+		var vl VersionList
 		err := vl.UnmarshalXDR(dbi.Value())
 		if err != nil {
 			panic(err)
@@ -593,7 +600,7 @@ func (db *Instance) checkGlobals(folder []byte, globalSize *sizeTracker) {
 	var fk []byte
 	for dbi.Next() {
 		gk := dbi.Key()
-		var vl versionList
+		var vl VersionList
 		err := vl.UnmarshalXDR(dbi.Value())
 		if err != nil {
 			panic(err)
@@ -605,7 +612,7 @@ func (db *Instance) checkGlobals(folder []byte, globalSize *sizeTracker) {
 		// we find those and clear them out.
 
 		name := db.globalKeyName(gk)
-		var newVL versionList
+		var newVL VersionList
 		for i, version := range vl.versions {
 			fk = db.deviceKeyInto(fk[:cap(fk)], folder, version.device, name)
 
